@@ -60,10 +60,15 @@ __all__ = (
     "PrometheusInfoTypeDef",
     "PrometheusTypeDef",
     "S3TypeDef",
+    "SaslTypeDef",
+    "ScramTypeDef",
     "StateInfoTypeDef",
     "StorageInfoTypeDef",
     "TlsTypeDef",
+    "UnprocessedScramSecretTypeDef",
     "ZookeeperNodeInfoTypeDef",
+    "BatchAssociateScramSecretResponseTypeDef",
+    "BatchDisassociateScramSecretResponseTypeDef",
     "CreateClusterResponseTypeDef",
     "CreateConfigurationResponseTypeDef",
     "DeleteClusterResponseTypeDef",
@@ -80,6 +85,7 @@ __all__ = (
     "ListConfigurationsResponseTypeDef",
     "ListKafkaVersionsResponseTypeDef",
     "ListNodesResponseTypeDef",
+    "ListScramSecretsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "OpenMonitoringInfoTypeDef",
     "PaginatorConfigTypeDef",
@@ -142,7 +148,7 @@ BrokerSoftwareInfoTypeDef = TypedDict(
 )
 
 ClientAuthenticationTypeDef = TypedDict(
-    "ClientAuthenticationTypeDef", {"Tls": "TlsTypeDef"}, total=False
+    "ClientAuthenticationTypeDef", {"Sasl": "SaslTypeDef", "Tls": "TlsTypeDef"}, total=False
 )
 
 _RequiredCloudWatchLogsTypeDef = TypedDict("_RequiredCloudWatchLogsTypeDef", {"Enabled": bool})
@@ -338,6 +344,10 @@ class S3TypeDef(_RequiredS3TypeDef, _OptionalS3TypeDef):
     pass
 
 
+SaslTypeDef = TypedDict("SaslTypeDef", {"Scram": "ScramTypeDef"}, total=False)
+
+ScramTypeDef = TypedDict("ScramTypeDef", {"Enabled": bool}, total=False)
+
 StateInfoTypeDef = TypedDict("StateInfoTypeDef", {"Code": str, "Message": str}, total=False)
 
 StorageInfoTypeDef = TypedDict(
@@ -346,6 +356,12 @@ StorageInfoTypeDef = TypedDict(
 
 TlsTypeDef = TypedDict("TlsTypeDef", {"CertificateAuthorityArnList": List[str]}, total=False)
 
+UnprocessedScramSecretTypeDef = TypedDict(
+    "UnprocessedScramSecretTypeDef",
+    {"ErrorCode": str, "ErrorMessage": str, "SecretArn": str},
+    total=False,
+)
+
 ZookeeperNodeInfoTypeDef = TypedDict(
     "ZookeeperNodeInfoTypeDef",
     {
@@ -358,6 +374,18 @@ ZookeeperNodeInfoTypeDef = TypedDict(
     total=False,
 )
 
+BatchAssociateScramSecretResponseTypeDef = TypedDict(
+    "BatchAssociateScramSecretResponseTypeDef",
+    {"ClusterArn": str, "UnprocessedScramSecrets": List["UnprocessedScramSecretTypeDef"]},
+    total=False,
+)
+
+BatchDisassociateScramSecretResponseTypeDef = TypedDict(
+    "BatchDisassociateScramSecretResponseTypeDef",
+    {"ClusterArn": str, "UnprocessedScramSecrets": List["UnprocessedScramSecretTypeDef"]},
+    total=False,
+)
+
 CreateClusterResponseTypeDef = TypedDict(
     "CreateClusterResponseTypeDef",
     {
@@ -430,7 +458,11 @@ DescribeConfigurationRevisionResponseTypeDef = TypedDict(
 
 GetBootstrapBrokersResponseTypeDef = TypedDict(
     "GetBootstrapBrokersResponseTypeDef",
-    {"BootstrapBrokerString": str, "BootstrapBrokerStringTls": str},
+    {
+        "BootstrapBrokerString": str,
+        "BootstrapBrokerStringTls": str,
+        "BootstrapBrokerStringSaslScram": str,
+    },
     total=False,
 )
 
@@ -476,6 +508,10 @@ ListNodesResponseTypeDef = TypedDict(
     total=False,
 )
 
+ListScramSecretsResponseTypeDef = TypedDict(
+    "ListScramSecretsResponseTypeDef", {"NextToken": str, "SecretArnList": List[str]}, total=False
+)
+
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef", {"Tags": Dict[str, str]}, total=False
 )
